@@ -66,10 +66,9 @@ class Playbook(object):
     class NoPasswordException(Exception):
         pass
 
-    def __init__(self, **kwargs):
-        self.args = kwargs
-        self.share_dir = settings.SHARE_DIR
-        self.config_dir = settings.CONFIG_DIR
+    def __init__(self, config_dir, share_dir):
+        self.config_dir = config_dir
+        self.share_dir = share_dir
 
     @staticmethod
     def is_encrypted(p):
@@ -146,13 +145,16 @@ class Playbook(object):
             },
         )
 
-    def run(self):
-        self.ensure_decrypted()
-        if not self.args['args']:
+    def run_from_cli(self, **kwargs):
+        if not kwargs['args']:
             args = [
                 '--private-key', f'{self.config_dir}/infrastructure_key',
                 f'{self.config_dir}/enough-playbook.yml'
             ]
         else:
-            args = self.args['args'][1:]
+            args = kwargs['args'][1:]
+        self.run(*args)
+
+    def run(self, *args):
+        self.ensure_decrypted()
         self.bake()(*args)
