@@ -4,12 +4,18 @@ import shutil
 import tempfile
 
 from enough import settings
-from enough.common import openstack, docker
+from enough.common import openstack
+from enough.common import docker
+from enough.common import dotenough
 from enough.common import tcp
 
 
 class Host(ABC):
 
+    def __init__(self, config_dir, share_dir):
+        self.config_dir = config_dir
+        self.share_dir = share_dir
+
     @abstractmethod
     def create_or_update(self):
         pass
@@ -27,11 +33,15 @@ class HostDocker(Host):
 
     class DockerInfrastructure(docker.Docker):
 
+        def __init__(self, config_dir, **kwargs):
+            self.config_dir = config_dir
+            super().__init__(**kwargs)
+
         def create_image(self):
             name = super().create_image()
             dockerfile = os.path.join(self.root, 'internal/data/infrastructure.dockerfile')
             with tempfile.TemporaryDirectory() as d:
-                shutil.copy(f'{settings.CONFIG_DIR}/infrastructure_key.pub', d)
+                shutil.copy(f'{self.config_dir}/infrastructure_key.pub', d)
                 return self._create_image(None,
                                           '--build-arg', f'IMAGE_NAME={name}',
                                           '-f', dockerfile, d)
@@ -40,9 +50,12 @@ class HostDocker(Host):
             f = os.path.join(self.root, 'internal/data/infrastructure-docker-compose.yml')
             return self.replace_content(open(f).read())
 
-    def __init__(self, **kwargs):
+    def __init__(self, config_dir, share_dir, **kwargs):
+        super().__init__(config_dir, share_dir)
         self.args = kwargs
-        self.d = HostDocker.DockerInfrastructure(**self.args)
+        self.dotenough = dotenough.DotEnoughDocker(config_dir, self.args['domain'])
+        self.dotenough.ensure()
+        self.d = HostDocker.DockerInfrastructure(config_dir, **self.args)
 
     def create_or_update(self):
         self.d.create_network(self.args['domain'])
@@ -51,7 +64,7 @@ class HostDocker(Host):
         if not port:
             port = tcp.free_port()
             self.args['port'] = port
-            self.d = HostDocker.DockerInfrastructure(**self.args)
+            self.d = HostDocker.DockerInfrastructure(self.config_dir, **self.args)
             self.d.create_or_update()
         return {
             'ipv4': self.d.get_ip(),
@@ -69,27 +82,34 @@ class HostDocker(Host):
 
 class HostOpenStack(Host):
 
-    def __init__(self, **kwargs):
+    def __init__(self, config_dir, share_dir, **kwargs):
+        super().__init__(config_dir, share_dir)
         self.args = kwargs
+        self.dotenough = dotenough.DotEnoughOpenStack(config_dir, self.args['domain'])
+        self.dotenough.ensure()
 
     def create_or_update(self):
-        s = openstack.Stack(self.args['clouds'],
-                            openstack.Heat.get_stack_definition(self.args['name']))
-        s.set_public_key(f'{settings.CONFIG_DIR}/infrastructure_key.pub')
+        h = openstack.Heat(self.config_dir, self.args['clouds'])
+        s = openstack.Stack(self.config_dir,
+                            self.args['clouds'],
+                            h.get_stack_definition(self.args['name']))
+        s.set_public_key(f'{self.config_dir}/infrastructure_key.pub')
         return s.create_or_update()
 
     def delete(self):
+        h = openstack.Heat(self.config_dir, self.args['clouds'])
         for name in self.args['name']:
-            s = openstack.Stack(self.args['clouds'],
-                                openstack.Heat.get_stack_definition(name))
+            s = openstack.Stack(self.config_dir,
+                                self.args['clouds'],
+                                h.get_stack_definition(name))
             s.delete()
 
     def write_inventory(self):
-        openstack.Heat(self.args['clouds']).write_inventory()
+        openstack.Heat(self.config_dir, self.args['clouds']).write_inventory()
 
 
 def host_factory(**kwargs):
     if kwargs['driver'] == 'openstack':
-        return HostOpenStack(**kwargs)
+        return HostOpenStack(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
     else:
-        return HostDocker(**kwargs)
+        return HostDocker(settings.CONFIG_DIR, settings.SHARE_DIR, **kwargs)
