@@ -15,12 +15,14 @@ import yaml
 from enough import settings
 from enough.common.retry import retry
 
+log = logging.getLogger(__name__)
+
 
 class OpenStackBase(object):
 
-    def __init__(self, config_file):
+    def __init__(self, config_dir, config_file):
+        self.config_dir = config_dir
         self.config_file = config_file
-        log = logging.getLogger(__name__)
         self.o = sh.openstack.bake(
             '--os-cloud=ovh',
             _tee=True,
@@ -32,8 +34,8 @@ class OpenStackBase(object):
 
 class Stack(OpenStackBase):
 
-    def __init__(self, config_file, definition=None):
-        super().__init__(config_file)
+    def __init__(self, config_dir, config_file, definition=None):
+        super().__init__(config_dir, config_file)
         self.definition = definition
 
     def get_template(self):
@@ -56,6 +58,7 @@ class Stack(OpenStackBase):
             parameters.append(f"--parameter=volume_name={d['volumes'][0]['name']}")
         if 'network' in d:
             parameters.append(f'--parameter=network={network}')
+        log.info(f'_create_or_update: {d["name"]} {parameters}')
         self.o.stack(action, d['name'],
                      '--wait', '--timeout=600',
                      '--template', self.get_template(),
@@ -95,11 +98,14 @@ class Stack(OpenStackBase):
 
     def create(self):
         try:
+            log.info('create on network Ext-Net')
             info = self._create_or_update('create', 'Ext-Net')
         except sh.ErrorReturnCode_1:
+            log.info('retry create on network Ext-Net')
             # retry once because there is no way to increase the timeout and create fails often
             info = self._create_or_update('update', 'Ext-Net')
         if self.definition.get('network', 'Ext-Net') != 'Ext-Net':
+            log.info(f'create on network {self.definition["network"]}')
             # wait for the interface to settle before removing it
             self.wait_for_ssh(info['ipv4'], info['port'])
             server = self.definition['name']
@@ -122,22 +128,19 @@ class Stack(OpenStackBase):
 
 class Heat(OpenStackBase):
 
-    @staticmethod
-    def get_stack_definitions(share_dir=settings.SHARE_DIR,
-                              config_dir=settings.CONFIG_DIR):
+    def get_stack_definitions(self, share_dir=settings.SHARE_DIR):
         args = ['-i', f'{share_dir}/inventory',
-                '-i', f'{config_dir}/inventory',
+                '-i', f'{self.config_dir}/inventory',
                 '--vars', '--list']
-        password_file = f'{config_dir}.pass'
+        password_file = f'{self.config_dir}.pass'
         if os.path.exists(password_file):
             args.extend(['--vault-password-file', password_file])
         r = sh.ansible_inventory(*args)
         inventory = json.loads(r.stdout)
         return inventory['_meta']['hostvars']
 
-    @staticmethod
-    def get_stack_definition(host):
-        h = Heat.get_stack_definitions()[host]
+    def get_stack_definition(self, host):
+        h = self.get_stack_definitions()[host]
         definition = {
             'name': host,
             'port': h.get('ansible_port', '22'),
@@ -158,9 +161,10 @@ class Heat(OpenStackBase):
         return True
 
     def create_or_update(self, names, public_key):
+        h = Heat(self.config_dir, self.config_file)
         r = {}
         for name in names:
-            s = Stack(self.config_file, Heat.get_stack_definition(name))
+            s = Stack(self.config_dir, self.config_file, h.get_stack_definition(name))
             s.set_public_key(public_key)
             r[name] = s.create_or_update()
         return r
@@ -180,10 +184,10 @@ class Heat(OpenStackBase):
         )
 
     def write_inventory(self):
-        names = Stack(self.config_file).list()
+        names = Stack(self.config_dir, self.config_file).list()
         inventory = self.to_inventory(self.create_or_update(
-            names, f'{settings.CONFIG_DIR}/infrastructure_key.pub'))
-        d = f'{settings.CONFIG_DIR}/inventory'
+            names, f'{self.config_dir}/infrastructure_key.pub'))
+        d = f'{self.config_dir}/inventory'
         if not os.path.exists(d):
             os.makedirs(d)
         open(f'{d}/hosts.yml', 'w').write(inventory)
@@ -191,12 +195,13 @@ class Heat(OpenStackBase):
     def create_test_subdomain(self, domain):
         # exclusively when running from molecule
         assert os.path.exists('molecule.yml')
-        d = f"{settings.CONFIG_DIR}/inventory/group_vars/all"
+        d = f"{self.config_dir}/inventory/group_vars/all"
         assert os.path.exists(d)
-        if 'bind-host' not in Stack(self.config_file).list():
+        if 'bind-host' not in Stack(self.config_dir, self.config_file).list():
             return None
-        s = Stack(self.config_file, Heat.get_stack_definition('bind-host'))
-        s.set_public_key(f'{settings.CONFIG_DIR}/infrastructure_key.pub')
+        h = Heat(self.config_dir, self.config_file)
+        s = Stack(self.config_dir, self.config_file, h.get_stack_definition('bind-host'))
+        s.set_public_key(f'{self.config_dir}/infrastructure_key.pub')
         bind_host = s.create_or_update()
 
         # reverse so the leftmost part varies, for human readability
@@ -204,6 +209,7 @@ class Heat(OpenStackBase):
         subdomain = base64.b32encode(s.encode('ascii')).decode('ascii').lower()
 
         fqdn = f'{subdomain}.test.{domain}'
+        log.info(f'creating test subdomain {fqdn}')
 
         token = os.environ['ENOUGH_API_TOKEN']
 
@@ -227,8 +233,8 @@ class OpenStackLeftovers(Exception):
 
 class OpenStack(OpenStackBase):
 
-    def __init__(self, config_file):
-        super().__init__(config_file)
+    def __init__(self, config_dir, config_file):
+        super().__init__(config_dir, config_file)
         self.config = yaml.load(open(config_file))
         self.auth = self.config['clouds']['ovh']['auth']
         self.horizon_session = None
@@ -323,8 +329,7 @@ class OpenStack(OpenStackBase):
         images = self.o.image.list('--private')
         return servers.strip() == '' and images.strip() == ''
 
-    @staticmethod
-    def allocate_cloud(directory, destination):
+    def allocate_cloud(self, directory, destination):
         if os.path.exists(destination):
             return True
         for f in sorted(os.listdir(directory)):
@@ -332,8 +337,8 @@ class OpenStack(OpenStackBase):
             os.link(origin, destination)
             if (
                     os.stat(origin).st_nlink == 2 and
-                    OpenStack(origin).region_empty() and
-                    Heat(origin).is_working()
+                    OpenStack(self.config_dir, origin).region_empty() and
+                    Heat(self.config_dir, origin).is_working()
             ):
                 return origin
             else:
