@@ -1,9 +1,11 @@
-from enough.common import ansible_utils
 import json
 import pytest
 import shutil
 import yaml
 
+from enough import settings
+from enough.common import ansible_utils
+
 
 def test_parse_output():
     data = {"changed": False}
@@ -19,13 +21,13 @@ def test_get_variable():
 
 
 def test_playbook_roles_path():
-    p = ansible_utils.Playbook()
+    p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
     r = p.roles_path('.')
     assert '/infrastructure/' in r
 
 
 def test_playbook_ensure_decrypted(tmpdir):
-    p = ansible_utils.Playbook()
+    p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
     shutil.copytree('tests/enough/common/test_ansible_utils/domain.com',
                     f'{tmpdir}/domain.com')
     c = f'{tmpdir}/domain.com'
@@ -56,11 +58,8 @@ def test_playbook_ensure_decrypted(tmpdir):
 
 
 def test_playbook_run_with_args(capsys, caplog):
-    kwargs = {
-        'args': ['--', 'tests/enough/common/test_ansible_utils/playbook-ok.yml'],
-    }
-    p = ansible_utils.Playbook(**kwargs)
-    p.run()
+    p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
+    p.run('tests/enough/common/test_ansible_utils/playbook-ok.yml')
     out, err = capsys.readouterr()
     assert 'OK_PLAYBOOK' in caplog.text
     assert 'OK_IMPORTED' in caplog.text
@@ -79,6 +78,6 @@ def test_playbook_run_no_args(mocker):
     kwargs = {
         'args': [],
     }
-    p = ansible_utils.Playbook(**kwargs)
-    p.run()
+    p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
+    p.run_from_cli(**kwargs)
     assert 'playbook' in called
