@@ -16,8 +16,8 @@ def test_populate_config(tmpdir):
     h.config_dir = tmpdir
     h.populate_config()
 
-    domain = yaml.load(open(f'{tmpdir}/inventory/group_vars/all/domain.yml'))
-    assert 'letsencrypt_staging' in domain
+    domain = yaml.load(open(f'{tmpdir}/inventory/group_vars/all/certificate.yml'))
+    assert 'certificate_authority' in domain
 
 
 def test_create_hosts(tmpdir, mocker):
