@@ -6,6 +6,7 @@ import requests_mock as requests_mock_module
 
 from tests.modified_environ import modified_environ
 
+from enough import settings
 from enough.common.openstack import Stack, Heat, OpenStack
 
 
@@ -26,7 +27,7 @@ def test_stack_create_or_update_default(openstack_name):
             },
         ],
     }
-    s = Stack('inventory/group_vars/all/clouds.yml', d)
+    s = Stack(settings.CONFIG_DIR, 'inventory/group_vars/all/clouds.yml', d)
     s.set_public_key('infrastructure_key.pub')
     r = s.create_or_update()
     assert r['port'] == '22'
@@ -37,6 +38,8 @@ def test_stack_create_or_update_default(openstack_name):
 
 @pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
                     reason='skip integration test')
+@pytest.mark.skipif('SKIP_NETWORK_OPENSTACK_INTEGRATION_TESTS' in os.environ,
+                    reason='skip network integration test')
 def test_stack_create_or_update_network(openstack_name):
     o = OpenStack('inventory/group_vars/all/clouds.yml')
     if 'internal' not in o.o.network.list('-f=value', '-c=Name'):
@@ -53,7 +56,7 @@ def test_stack_create_or_update_network(openstack_name):
             },
         ],
     }
-    s = Stack('inventory/group_vars/all/clouds.yml', d)
+    s = Stack(settings.CONFIG_DIR, 'inventory/group_vars/all/clouds.yml', d)
     s.set_public_key('infrastructure_key.pub')
     r = s.create_or_update()
     assert r['port'] == '22'
@@ -69,12 +72,12 @@ def test_stack_create_or_update_network(openstack_name):
 @pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
                     reason='skip integration test')
 def test_heat_is_working(tmpdir):
-    o = OpenStack('inventory/group_vars/all/clouds.yml')
+    o = OpenStack('.', 'inventory/group_vars/all/clouds.yml')
     assert o.generate_clouds(tmpdir)
     heat_paths = []
     for f in sorted(os.listdir(tmpdir)):
         path = f'{tmpdir}/{f}'
-        if Heat(path).is_working():
+        if Heat('.', path).is_working():
             heat_paths.append(path)
     heat_regions = []
     for path in heat_paths:
@@ -85,15 +88,17 @@ def test_heat_is_working(tmpdir):
 
 
 def test_heat_definition():
-    definitions = Heat.get_stack_definitions()
+    h = Heat('.', 'inventory/group_vars/all/clouds.yml')
+    definitions = h.get_stack_definitions()
     assert 'bind-host' in definitions
-    definition = Heat.get_stack_definition('bind-host')
+    definition = h.get_stack_definition('bind-host')
     assert definition['name'] == 'bind-host'
 
 
 def test_heat_definition_encrypted():
     d = 'tests/enough/common/test_openstack/config_dir'
-    definitions = Heat.get_stack_definitions(share_dir=d, config_dir=d)
+    h = Heat(d, 'inventory/group_vars/all/clouds.yml')
+    definitions = h.get_stack_definitions(share_dir=d)
     assert 'my-host' in definitions
     assert definitions['my-host']['myvariable'] == 'myvalue'
 
@@ -101,7 +106,7 @@ def test_heat_definition_encrypted():
 def test_create_test_subdomain_no_bind(mocker):
     mocker.patch('os.path.exists', return_value=True)
     mocker.patch('enough.common.openstack.Stack.list', return_value=[])
-    h = Heat('inventory/group_vars/all/clouds.yml')
+    h = Heat('.', 'inventory/group_vars/all/clouds.yml')
     assert h.create_test_subdomain('my.tld') is None
 
 
@@ -118,7 +123,7 @@ def test_create_test_subdomain_with_bind(tmpdir, mocker, requests_mock):
     })
     mocker.patch('enough.common.openstack.Heat.get_stack_definition')
     requests_mock.post(requests_mock_module.ANY, status_code=201)
-    h = Heat('inventory/group_vars/all/clouds.yml')
+    h = Heat('.', 'inventory/group_vars/all/clouds.yml')
     with modified_environ(ENOUGH_API_TOKEN="TOKEN"):
         fqdn = h.create_test_subdomain('my.tld')
     assert '.test.my.tld' in fqdn
@@ -131,7 +136,7 @@ def test_create_test_subdomain_with_bind(tmpdir, mocker, requests_mock):
 @pytest.mark.skipif('SKIP_OPENSTACK_INTEGRATION_TESTS' in os.environ,
                     reason='skip integration test')
 def test_region_list():
-    o = OpenStack('inventory/group_vars/all/clouds.yml')
+    o = OpenStack('.', 'inventory/group_vars/all/clouds.yml')
     assert o.config['clouds']['ovh']['region_name'] in o.region_list()
 
 
@@ -139,16 +144,16 @@ def test_region_list():
                     reason='skip integration test')
 def test_region_empty(openstack_name):
     clouds_file = 'inventory/group_vars/all/clouds.yml'
-    if OpenStack(clouds_file).region_empty():
+    if OpenStack('.', clouds_file).region_empty():
         c = sh.openstack.bake('--os-cloud=ovh', _env={
             'OS_CLIENT_CONFIG_FILE': clouds_file,
         })
         c.image.create('--file=/dev/null', openstack_name)
-    assert not OpenStack(clouds_file).region_empty()
+    assert not OpenStack('.', clouds_file).region_empty()
 
 
 def test_generate_clouds(tmpdir, mocker):
-    o = OpenStack('tests/enough/common/data/common/openstack/clouds.yml')
+    o = OpenStack('.', 'tests/enough/common/data/common/openstack/clouds.yml')
 
     directory = f'{tmpdir}/hosting'
 
@@ -174,7 +179,7 @@ def test_generate_clouds(tmpdir, mocker):
 
 
 def test_allocate_cloud(tmpdir, mocker):
-    o = OpenStack('tests/enough/common/data/common/openstack/clouds.yml')
+    o = OpenStack('.', 'tests/enough/common/data/common/openstack/clouds.yml')
 
     mocker.patch('enough.common.openstack.OpenStack.region_list',
                  return_value=['REGION1', 'REGION2'])
